@@ -16,6 +16,7 @@ from neutron_lib.api.definitions import agent
 from neutron_lib.api.definitions import agent_resources_synced
 from neutron_lib.api.definitions import agent_sort_key
 from neutron_lib.api.definitions import allowedaddresspairs
+from neutron_lib.api.definitions import allowedaddresspairs_atomic
 from neutron_lib.api.definitions import auto_allocated_topology
 from neutron_lib.api.definitions import availability_zone
 from neutron_lib.api.definitions import availability_zone_filter
@@ -52,6 +53,7 @@ from neutron_lib.api.definitions import fip_pf_detail
 from neutron_lib.api.definitions import fip_pf_port_range
 from neutron_lib.api.definitions import fip_port_details
 from neutron_lib.api.definitions import firewall_v2
+from neutron_lib.api.definitions import firewall_v2_stdattrs
 from neutron_lib.api.definitions import flavors
 from neutron_lib.api.definitions import floating_ip_port_forwarding
 from neutron_lib.api.definitions import floatingip_autodelete_internal
@@ -62,7 +64,10 @@ from neutron_lib.api.definitions import ip_substring_port_filtering
 from neutron_lib.api.definitions import l2_adjacency
 from neutron_lib.api.definitions import l3
 from neutron_lib.api.definitions import l3_conntrack_helper
+from neutron_lib.api.definitions import l3_enable_default_route_bfd
+from neutron_lib.api.definitions import l3_enable_default_route_ecmp
 from neutron_lib.api.definitions import l3_ext_gw_mode
+from neutron_lib.api.definitions import l3_ext_gw_multihoming
 from neutron_lib.api.definitions import l3_ext_ha_mode
 from neutron_lib.api.definitions import l3_ext_ndp_proxy
 from neutron_lib.api.definitions import l3_flavors
@@ -77,6 +82,7 @@ from neutron_lib.api.definitions import multiprovidernet
 from neutron_lib.api.definitions import network
 from neutron_lib.api.definitions import network_availability_zone
 from neutron_lib.api.definitions import network_cascade_delete
+from neutron_lib.api.definitions import network_ha
 from neutron_lib.api.definitions import network_ip_availability
 from neutron_lib.api.definitions import network_mtu
 from neutron_lib.api.definitions import network_mtu_writable
@@ -84,6 +90,8 @@ from neutron_lib.api.definitions import network_segment_range
 from neutron_lib.api.definitions import pagination
 from neutron_lib.api.definitions import port
 from neutron_lib.api.definitions import port_device_profile
+from neutron_lib.api.definitions import port_hardware_offload_type
+from neutron_lib.api.definitions import port_hint_ovs_tx_steering
 from neutron_lib.api.definitions import port_hints
 from neutron_lib.api.definitions import port_mac_address_override
 from neutron_lib.api.definitions import port_mac_address_regenerate
@@ -124,6 +132,8 @@ from neutron_lib.api.definitions import routerservicetype
 from neutron_lib.api.definitions import security_groups_normalized_cidr
 from neutron_lib.api.definitions import security_groups_port_filtering
 from neutron_lib.api.definitions import security_groups_remote_address_group
+from neutron_lib.api.definitions import \
+    security_groups_rules_belongs_to_default_sg
 from neutron_lib.api.definitions import security_groups_shared_filtering
 from neutron_lib.api.definitions import segment
 from neutron_lib.api.definitions import segments_peer_subnet_host_routes
@@ -160,6 +170,7 @@ _ALL_API_DEFINITIONS = {
     agent_resources_synced,
     agent_sort_key,
     allowedaddresspairs,
+    allowedaddresspairs_atomic,
     auto_allocated_topology,
     availability_zone,
     availability_zone_filter,
@@ -191,6 +202,7 @@ _ALL_API_DEFINITIONS = {
     filter_validation,
     fip64,
     firewall_v2,
+    firewall_v2_stdattrs,
     fip_distributed,
     fip_pf_detail,
     fip_port_details,
@@ -210,6 +222,9 @@ _ALL_API_DEFINITIONS = {
     l3_ext_ha_mode,
     l3_ext_ndp_proxy,
     l3_flavors,
+    l3_ext_gw_multihoming,
+    l3_enable_default_route_bfd,
+    l3_enable_default_route_ecmp,
     l3_ndp_proxy,
     l3_port_ip_change_not_allowed,
     local_ip,
@@ -221,6 +236,7 @@ _ALL_API_DEFINITIONS = {
     network,
     network_availability_zone,
     network_cascade_delete,
+    network_ha,
     network_ip_availability,
     network_mtu,
     network_mtu_writable,
@@ -228,7 +244,9 @@ _ALL_API_DEFINITIONS = {
     pagination,
     port,
     port_device_profile,
+    port_hardware_offload_type,
     port_hints,
+    port_hint_ovs_tx_steering,
     port_mac_address_override,
     port_mac_address_regenerate,
     port_numa_affinity_policy,
@@ -268,6 +286,7 @@ _ALL_API_DEFINITIONS = {
     security_groups_normalized_cidr,
     security_groups_port_filtering,
     security_groups_remote_address_group,
+    security_groups_rules_belongs_to_default_sg,
     security_groups_shared_filtering,
     segment,
     segments_peer_subnet_host_routes,
