@@ -18,10 +18,13 @@ import datetime
 
 from oslo_context import context as oslo_context
 from oslo_db.sqlalchemy import enginefacade
+from oslo_log import log as logging
 
 from neutron_lib.db import api as db_api
 from neutron_lib.policy import _engine as policy_engine
 
+LOG = logging.getLogger(__name__)
+
 
 class ContextBase(oslo_context.RequestContext):
     """Security context and request information.
@@ -47,10 +50,11 @@ class ContextBase(oslo_context.RequestContext):
         if not timestamp:
             timestamp = datetime.datetime.utcnow()
         self.timestamp = timestamp
-        self.is_advsvc = is_advsvc
-        if self.is_advsvc is None:
-            self.is_advsvc = (self.is_admin or
-                              policy_engine.check_is_advsvc(self))
+        self._is_advsvc = is_advsvc
+        if self._is_advsvc is None:
+            self._is_advsvc = (self.is_admin or
+                               policy_engine.check_is_advsvc(self))
+        self._is_service_role = policy_engine.check_is_service_role(self)
         if self.is_admin is None:
             self.is_admin = policy_engine.check_is_admin(self)
 
@@ -70,6 +74,23 @@ class ContextBase(oslo_context.RequestContext):
     def tenant_name(self, tenant_name):
         self.project_name = tenant_name
 
+    @property
+    def is_service_role(self):
+        # TODO(slaweq): we will not need to check ContextBase._is_advsvc once
+        # we will get rid of the old API policies
+        return self._is_service_role or self._is_advsvc
+
+    @property
+    def is_advsvc(self):
+        # TODO(slaweq): this property should be removed once we will get rid
+        # of old policy rules and only new, S-RBAC rules will be available as
+        # then we will use ContextBase.is_service_role instead
+        LOG.warning("Method 'is_advsvc' is deprecated since 2023.2 release "
+                    "(neutron-lib 3.8.0) and will be removed once support for "
+                    "the old RBAC API policies will be removed from Neutron. "
+                    "Please use method 'is_service_role' instead.")
+        return self.is_service_role
+
     def to_dict(self):
         context = super().to_dict()
         context.update({
